OC.L10N.register(
    "groupfolders",
    {
    "Denied (Inherited permission)" : "Rifuzita (heredita permeso)",
    "Allowed (Inherited permission)" : "Permesita (heredita permeso)",
    "Denied" : "Rifuzita",
    "Allowed" : "Permesita",
    "Access denied" : "Aliro malpermesata",
    "Inherit permission" : "Heredita permeso",
    "Deny" : "Rifuzi",
    "Allow" : "Permesi",
    "Group" : "Grupo",
    "Read" : "Legi",
    "Write" : "Skribi",
    "Create" : "Krei",
    "Delete" : "Forigi",
    "Share" : "Kunhavigi",
    "You" : "Vi",
    "Remove access rule" : "Forigi alirregulon",
    "Select a user or group" : "Elektu uzanton aŭ grupon",
    "Add group" : "Aldoni grupon",
    "Unlimited" : "Senlima",
    "Delete \"{folderName}\"?" : "Ĉu forigi „{folderName}“?",
    "Folder name" : "Dosierujnomo",
    "Quota" : "Kvoto",
    "Advanced Permissions" : "Detalaj permesoj",
    "Previous" : "Antaŭa",
    "Next" : "Posten",
    "User" : "Uzanto",
    "Unknown" : "Nekonata",
    "None" : "Nenio",
    "{size} used" : "{size} uzataj",
    "Unset" : "Malprotekti"
},
"nplurals=2; plural=(n != 1);");
